# Tunes: Example XEP-0118 (User Tune) user.
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
# Homepage: http://thp.io/2007/python-jabberbot/

"""
When the bot is connected, use commands like:

set artist Metallica
set title Bad Seed

The bot will update its tune and log the outgoing packet to stdout.
"""

import sys
from jabberbot import JabberBot, botcmd

class Tunes(JabberBot):
    def __init__(self, username, password):
        JabberBot.__init__(self, username, password)
        self.track = { 'file': 'test.mp3' }

    @botcmd
    def set(self, message, args):
        'set track properties'
        args = args.strip().split(' ')
        if len(args) < 2 or args[0] not in ('artist', 'title', 'album', 'source', 'pos', 'track', 'time', 'uri'):
            return 'Usage: set {artist|title|album|source|pos|track|time|uri} value'
        self.track[args[0]] = ' '.join(args[1:])
        self.send_tune(self.track, True)

if __name__ == '__main__':
    if len(sys.argv) < 3:
        print 'Usage: %s login@host password' % sys.argv[0]
        sys.exit(1)
    bot = Tunes(sys.argv[1], sys.argv[2])
    bot.serve_forever()




#!/usr/bin/python

# JabberBot: A simple jabber/xmpp bot framework
# Copyright (c) 2007-2011 Thomas Perl <thp.io/about>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

#
# This is an example JabberBot that serves as broadcasting server.
# Users can subscribe/unsubscribe to messages and send messages 
# by using "broadcast". It also shows how to send message from 
# outside the main loop, so you can inject messages into the bot 
# from other threads or processes, too.
#

from jabberbot import JabberBot, botcmd

import threading
import time 
import logging

# Fill in the JID + Password of your JabberBot here...
(JID, PASSWORD) = ('my-jabber-id@jabberserver.example.org','my-password')

class BroadcastingJabberBot(JabberBot):
    """This is a simple broadcasting client. Use "subscribe" to subscribe to broadcasts, "unsubscribe" to unsubscribe and "broadcast" + message to send out a broadcast message. Automatic messages will be sent out all 60 seconds."""

    def __init__( self, jid, password, res = None):
        super( BroadcastingJabberBot, self).__init__( jid, password, res)
        # create console handler
        chandler = logging.StreamHandler()
        # create formatter
        formatter = logging.Formatter("%(asctime)s - %(name)s - %(levelname)s - %(message)s")
        # add formatter to handler
        chandler.setFormatter(formatter)
        # add handler to logger
        self.log.addHandler(chandler)
        # set level to INFO
        self.log.setLevel(logging.INFO)

        self.users = []
        self.message_queue = []
        self.thread_killed = False

    @botcmd
    def subscribe( self, mess, args):
        """Subscribe to the broadcast list"""
        user = mess.getFrom()
        if user in self.users:
            return 'You are already subscribed.'
        else:
            self.users.append( user)
            self.log.info( '%s subscribed to the broadcast.' % user)
            return 'You are now subscribed.'

    @botcmd
    def unsubscribe( self, mess, args):
        """Unsubscribe from the broadcast list"""
        user = mess.getFrom()
        if not user in self.users:
            return 'You are not subscribed!'
        else:
            self.users.remove( user)
            self.log.info( '%s unsubscribed from the broadcast.' % user)
            return 'You are now unsubscribed.'
    
    # You can use the "hidden" parameter to hide the
    # command from JabberBot's 'help' list
    @botcmd(hidden=True)
    def broadcast( self, mess, args):
        """Sends out a broadcast, supply message as arguments (e.g. broadcast hello)"""
        self.message_queue.append( 'broadcast: %s (from %s)' % ( args, str(mess.getFrom()), ))
        self.log.info( '%s sent out a message to %d users.' % ( str(mess.getFrom()), len(self.users),))

    def idle_proc( self):
        if not len(self.message_queue):
            return

        # copy the message queue, then empty it
        messages = self.message_queue
        self.message_queue = []

        for message in messages:
            if len(self.users):
                self.log.info('sending "%s" to %d user(s).' % ( message, len(self.users), ))
            for user in self.users:
                self.send( user, message)

    def thread_proc( self):
        while not self.thread_killed:
            self.message_queue.append('this is an automatic message, sent all 60 seconds :)')
            for i in range(60):
                time.sleep( 1)
                if self.thread_killed:
                    return


bc = BroadcastingJabberBot( JID, PASSWORD)

th = threading.Thread( target = bc.thread_proc)
bc.serve_forever( connect_callback = lambda: th.start())
bc.thread_killed = True





# TwitterBot: Example Twitter but using python-jabberbot
# Copyright (c) 2008 Thomas Perl <thp.io/about>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
# Homepage: http://thp.io/2007/python-jabberbot/

import twitter
import jabberbot

botcmd = jabberbot.botcmd

# Configure your Jabber and Twitter authentication and secret phrase
JABBERBOT_USER = 'jabberbot@example.com'
JABBERBOT_PASS = 'jabberbotpassword'
TWITTER_USERNAME = 'yourtwitterusername'
TWITTER_PASSWORD = 'yourtwitterpassword'
SECRETPHRASE = 'HelloMyTwitterBot!'

class TwitterBot(jabberbot.JabberBot):
    """
    This is a JabberBot that can interface with the Twitter webservice.
    Just set up a Jabber account for your Bot (set the JABBERBOT_USER and
    JABBERBOT_PASS variables accordingly) and then add your Twitter
    authentication data to TWITTER_USERNAME and TWITTER_PASSWORD.

    You can select a SECRETPHRASE that you will have to say to identify
    yourself to your JabberBot, so it will take commands from you.

    Additional requirements: python-twitter
    """

    denied = "Just what do you think you're doing, Dave?"
    himaster = "Good afternoon, gentlemen. I am a HAL 9000 computer."
    twitteruser = JABBERBOT_USER
    twitterpass = JABBERBOT_PASS

    def __init__(self, username, password, secret):
        jabberbot.JabberBot.__init__(self, self.twitteruser, self.twitterpass)
        self.master = ''
        self.secret = secret
        self.api = twitter.Api(username=username, password=password)

    def callback_message(self, conn, mess):
        # This is an example how you can set a "master" to listen to:
        if mess.getBody() == self.secret:
            self.master = mess.getFrom().getStripped()
            self.send(mess.getFrom(), self.himaster, mess)
            return
        if mess.getFrom().getStripped() != self.master:
            self.send(mess.getFrom(), self.denied, mess)
        else:
            return jabberbot.JabberBot.callback_message(self, conn, mess)

    @botcmd
    def friends(self, mess, args):
        """Return the friends"""
        return ', '.join([u.name for u in self.api.GetFriends()])

    @botcmd
    def post(self, mess, args):
        """Post a message to twitter"""
        posting = self.api.PostUpdate(args)
        return 'http://twitter.com/'+posting.GetUser().GetScreenName()+'/status/'+str(posting.GetId())


if __name__ == '__main__':
    bot = TwitterBot(TWITTER_USERNAME, TWITTER_PASSWORD, SECRETPHRASE)
    bot.serve_forever()




#!/usr/bin/env python
# coding: utf-8

# Copyright (C) 2010 Arthur Furlan <afurlan@afurlan.org>
# 
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 3 of the License, or
# (at your option) any later version.
# 
# On Debian systems, you can find the full text of the license in
# /usr/share/common-licenses/GPL-3


from jabberbot import JabberBot, botcmd
from datetime import datetime
import re

class MUCJabberBot(JabberBot):

    ''' Add features in JabberBot to allow it to handle specific
    caractheristics of multiple users chatroom (MUC). '''

    def __init__(self, *args, **kwargs):
        ''' Initialize variables. '''

        # answer only direct messages or not?
        self.only_direct = kwargs.get('only_direct', False)
        try:
            del kwargs['only_direct']
        except KeyError:
            pass

        # initialize jabberbot
        super(MUCJabberBot, self).__init__(*args, **kwargs)

        # create a regex to check if a message is a direct message
        user, domain = str(self.jid).split('@')
        self.direct_message_re = re.compile('^%s(@%s)?[^\w]? ' \
                % (user, domain))

    def callback_message(self, conn, mess):
        ''' Changes the behaviour of the JabberBot in order to allow
        it to answer direct messages. This is used often when it is
        connected in MUCs (multiple users chatroom). '''

        message = mess.getBody()
        if not message:
            return

        if self.direct_message_re.match(message):
            mess.setBody(' '.join(message.split(' ', 1)[1:]))
            return super(MUCJabberBot, self).callback_message(conn, mess)
        elif not self.only_direct:
            return super(MUCJabberBot, self).callback_message(conn, mess)


class Example(MUCJabberBot):

    @botcmd
    def date(self, mess, args):
        reply = datetime.now().strftime('%Y-%m-%d')
        self.send_simple_reply(mess, reply)


if __name__ == '__main__':

    username = 'username'
    password = 'password'
    nickname = 'nickname'
    chatroom = 'chatroom'

    mucbot = Example(username, password, only_direct=True)
    mucbot.join_room(chatroom, nickname)
    mucbot.serve_forever()



#!/usr/bin/env python
# Setup script for python-jabberbot
# by Thomas Perl <thp.io/about>

from distutils.core import setup

import os
import re
import sys

# Make sure that we import the local jabberbot module
sys.path.insert(0, os.path.dirname(os.path.abspath(__file__)))
import jabberbot


# How is the package going to be called?
PACKAGE = 'jabberbot'

# List the modules that need to be installed/packaged
MODULES = (
        'jabberbot',
)

# These metadata fields are simply taken from the Jabberbot module
VERSION = jabberbot.__version__
WEBSITE = jabberbot.__website__
LICENSE = jabberbot.__license__
DESCRIPTION = jabberbot.__doc__

# Extract name and e-mail ("Firstname Lastname <mail@example.org>")
AUTHOR, EMAIL = re.match(r'(.*) <(.*)>', jabberbot.__author__).groups()

setup(name=PACKAGE,
      version=VERSION,
      description=DESCRIPTION,
      author=AUTHOR,
      author_email=EMAIL,
      license=LICENSE,
      url=WEBSITE,
      py_modules=MODULES,
      download_url=WEBSITE+PACKAGE+'-'+VERSION+'.tar.gz')

